"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .anncsuerror import AnncsuError
    from .apierror import APIError
    from .elencoaccessigetpathparamop import (
        ElencoAccessiGetPathParamBadRequestError,
        ElencoAccessiGetPathParamBadRequestErrorData,
        ElencoAccessiGetPathParamInternalServerError,
        ElencoAccessiGetPathParamInternalServerErrorData,
        ElencoAccessiGetPathParamMethodNotAllowedError,
        ElencoAccessiGetPathParamMethodNotAllowedErrorData,
        ElencoAccessiGetPathParamNotFoundError,
        ElencoAccessiGetPathParamNotFoundErrorData,
        ElencoAccessiGetPathParamUnprocessableEntityError,
        ElencoAccessiGetPathParamUnprocessableEntityErrorData,
    )
    from .elencoaccessigetqueryparamop import (
        ElencoAccessiGetQueryParamBadRequestError,
        ElencoAccessiGetQueryParamBadRequestErrorData,
        ElencoAccessiGetQueryParamInternalServerError,
        ElencoAccessiGetQueryParamInternalServerErrorData,
        ElencoAccessiGetQueryParamMethodNotAllowedError,
        ElencoAccessiGetQueryParamMethodNotAllowedErrorData,
        ElencoAccessiGetQueryParamNotFoundError,
        ElencoAccessiGetQueryParamNotFoundErrorData,
        ElencoAccessiGetQueryParamUnprocessableEntityError,
        ElencoAccessiGetQueryParamUnprocessableEntityErrorData,
    )
    from .elencoaccessipostop import (
        ElencoAccessiPostBadRequestError,
        ElencoAccessiPostBadRequestErrorData,
        ElencoAccessiPostInternalServerError,
        ElencoAccessiPostInternalServerErrorData,
        ElencoAccessiPostMethodNotAllowedError,
        ElencoAccessiPostMethodNotAllowedErrorData,
        ElencoAccessiPostNotFoundError,
        ElencoAccessiPostNotFoundErrorData,
        ElencoAccessiPostUnprocessableEntityError,
        ElencoAccessiPostUnprocessableEntityErrorData,
    )
    from .elencoaccessiproggetpathparamop import (
        ElencoaccessiprogGetPathParamBadRequestError,
        ElencoaccessiprogGetPathParamBadRequestErrorData,
        ElencoaccessiprogGetPathParamInternalServerError,
        ElencoaccessiprogGetPathParamInternalServerErrorData,
        ElencoaccessiprogGetPathParamMethodNotAllowedError,
        ElencoaccessiprogGetPathParamMethodNotAllowedErrorData,
        ElencoaccessiprogGetPathParamNotFoundError,
        ElencoaccessiprogGetPathParamNotFoundErrorData,
        ElencoaccessiprogGetPathParamUnprocessableEntityError,
        ElencoaccessiprogGetPathParamUnprocessableEntityErrorData,
    )
    from .elencoaccessiproggetqueryparamop import (
        ElencoaccessiprogGetQueryParamBadRequestError,
        ElencoaccessiprogGetQueryParamBadRequestErrorData,
        ElencoaccessiprogGetQueryParamInternalServerError,
        ElencoaccessiprogGetQueryParamInternalServerErrorData,
        ElencoaccessiprogGetQueryParamMethodNotAllowedError,
        ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData,
        ElencoaccessiprogGetQueryParamNotFoundError,
        ElencoaccessiprogGetQueryParamNotFoundErrorData,
        ElencoaccessiprogGetQueryParamUnprocessableEntityError,
        ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData,
    )
    from .elencoaccessiprogpostop import (
        ElencoaccessiprogPostBadRequestError,
        ElencoaccessiprogPostBadRequestErrorData,
        ElencoaccessiprogPostInternalServerError,
        ElencoaccessiprogPostInternalServerErrorData,
        ElencoaccessiprogPostMethodNotAllowedError,
        ElencoaccessiprogPostMethodNotAllowedErrorData,
        ElencoaccessiprogPostNotFoundError,
        ElencoaccessiprogPostNotFoundErrorData,
        ElencoaccessiprogPostUnprocessableEntityError,
        ElencoaccessiprogPostUnprocessableEntityErrorData,
    )
    from .elencoodonimigetpathparamop import (
        ElencoOdonimiGetPathParamBadRequestError,
        ElencoOdonimiGetPathParamBadRequestErrorData,
        ElencoOdonimiGetPathParamInternalServerError,
        ElencoOdonimiGetPathParamInternalServerErrorData,
        ElencoOdonimiGetPathParamMethodNotAllowedError,
        ElencoOdonimiGetPathParamMethodNotAllowedErrorData,
        ElencoOdonimiGetPathParamNotFoundError,
        ElencoOdonimiGetPathParamNotFoundErrorData,
        ElencoOdonimiGetPathParamUnprocessableEntityError,
        ElencoOdonimiGetPathParamUnprocessableEntityErrorData,
    )
    from .elencoodonimigetqueryparamop import (
        ElencoOdonimiGetQueryParamBadRequestError,
        ElencoOdonimiGetQueryParamBadRequestErrorData,
        ElencoOdonimiGetQueryParamInternalServerError,
        ElencoOdonimiGetQueryParamInternalServerErrorData,
        ElencoOdonimiGetQueryParamMethodNotAllowedError,
        ElencoOdonimiGetQueryParamMethodNotAllowedErrorData,
        ElencoOdonimiGetQueryParamNotFoundError,
        ElencoOdonimiGetQueryParamNotFoundErrorData,
        ElencoOdonimiGetQueryParamUnprocessableEntityError,
        ElencoOdonimiGetQueryParamUnprocessableEntityErrorData,
    )
    from .elencoodonimipostop import (
        ElencoOdonimiPostBadRequestError,
        ElencoOdonimiPostBadRequestErrorData,
        ElencoOdonimiPostInternalServerError,
        ElencoOdonimiPostInternalServerErrorData,
        ElencoOdonimiPostMethodNotAllowedError,
        ElencoOdonimiPostMethodNotAllowedErrorData,
        ElencoOdonimiPostNotFoundError,
        ElencoOdonimiPostNotFoundErrorData,
        ElencoOdonimiPostUnprocessableEntityError,
        ElencoOdonimiPostUnprocessableEntityErrorData,
    )
    from .elencoodonimiproggetpathparamop import (
        ElencoodonimiprogGetPathParamBadRequestError,
        ElencoodonimiprogGetPathParamBadRequestErrorData,
        ElencoodonimiprogGetPathParamInternalServerError,
        ElencoodonimiprogGetPathParamInternalServerErrorData,
        ElencoodonimiprogGetPathParamMethodNotAllowedError,
        ElencoodonimiprogGetPathParamMethodNotAllowedErrorData,
        ElencoodonimiprogGetPathParamNotFoundError,
        ElencoodonimiprogGetPathParamNotFoundErrorData,
        ElencoodonimiprogGetPathParamUnprocessableEntityError,
        ElencoodonimiprogGetPathParamUnprocessableEntityErrorData,
    )
    from .elencoodonimiproggetqueryparamop import (
        ElencoodonimiprogGetQueryParamBadRequestError,
        ElencoodonimiprogGetQueryParamBadRequestErrorData,
        ElencoodonimiprogGetQueryParamInternalServerError,
        ElencoodonimiprogGetQueryParamInternalServerErrorData,
        ElencoodonimiprogGetQueryParamMethodNotAllowedError,
        ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData,
        ElencoodonimiprogGetQueryParamNotFoundError,
        ElencoodonimiprogGetQueryParamNotFoundErrorData,
        ElencoodonimiprogGetQueryParamUnprocessableEntityError,
        ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData,
    )
    from .elencoodonimiprogpostop import (
        ElencoodonimiprogPostBadRequestError,
        ElencoodonimiprogPostBadRequestErrorData,
        ElencoodonimiprogPostInternalServerError,
        ElencoodonimiprogPostInternalServerErrorData,
        ElencoodonimiprogPostMethodNotAllowedError,
        ElencoodonimiprogPostMethodNotAllowedErrorData,
        ElencoodonimiprogPostNotFoundError,
        ElencoodonimiprogPostNotFoundErrorData,
        ElencoodonimiprogPostUnprocessableEntityError,
        ElencoodonimiprogPostUnprocessableEntityErrorData,
    )
    from .esisteaccessogetpathparamop import (
        EsisteAccessoGetPathParamBadRequestError,
        EsisteAccessoGetPathParamBadRequestErrorData,
        EsisteAccessoGetPathParamInternalServerError,
        EsisteAccessoGetPathParamInternalServerErrorData,
        EsisteAccessoGetPathParamMethodNotAllowedError,
        EsisteAccessoGetPathParamMethodNotAllowedErrorData,
        EsisteAccessoGetPathParamUnprocessableEntityError,
        EsisteAccessoGetPathParamUnprocessableEntityErrorData,
    )
    from .esisteaccessogetqueryparamop import (
        EsisteAccessoGetQueryParamBadRequestError,
        EsisteAccessoGetQueryParamBadRequestErrorData,
        EsisteAccessoGetQueryParamInternalServerError,
        EsisteAccessoGetQueryParamInternalServerErrorData,
        EsisteAccessoGetQueryParamMethodNotAllowedError,
        EsisteAccessoGetQueryParamMethodNotAllowedErrorData,
        EsisteAccessoGetQueryParamUnprocessableEntityError,
        EsisteAccessoGetQueryParamUnprocessableEntityErrorData,
    )
    from .esisteaccessopostop import (
        EsisteAccessoPostBadRequestError,
        EsisteAccessoPostBadRequestErrorData,
        EsisteAccessoPostInternalServerError,
        EsisteAccessoPostInternalServerErrorData,
        EsisteAccessoPostMethodNotAllowedError,
        EsisteAccessoPostMethodNotAllowedErrorData,
        EsisteAccessoPostUnprocessableEntityError,
        EsisteAccessoPostUnprocessableEntityErrorData,
    )
    from .esisteodonimogetpathparamop import (
        EsisteOdonimoGetPathParamBadRequestError,
        EsisteOdonimoGetPathParamBadRequestErrorData,
        EsisteOdonimoGetPathParamInternalServerError,
        EsisteOdonimoGetPathParamInternalServerErrorData,
        EsisteOdonimoGetPathParamMethodNotAllowedError,
        EsisteOdonimoGetPathParamMethodNotAllowedErrorData,
        EsisteOdonimoGetPathParamUnprocessableEntityError,
        EsisteOdonimoGetPathParamUnprocessableEntityErrorData,
    )
    from .esisteodonimogetqueryparamop import (
        EsisteOdonimoGetQueryParamBadRequestError,
        EsisteOdonimoGetQueryParamBadRequestErrorData,
        EsisteOdonimoGetQueryParamInternalServerError,
        EsisteOdonimoGetQueryParamInternalServerErrorData,
        EsisteOdonimoGetQueryParamMethodNotAllowedError,
        EsisteOdonimoGetQueryParamMethodNotAllowedErrorData,
        EsisteOdonimoGetQueryParamUnprocessableEntityError,
        EsisteOdonimoGetQueryParamUnprocessableEntityErrorData,
    )
    from .esisteodonimopostop import (
        EsisteOdonimoPostBadRequestError,
        EsisteOdonimoPostBadRequestErrorData,
        EsisteOdonimoPostInternalServerError,
        EsisteOdonimoPostInternalServerErrorData,
        EsisteOdonimoPostMethodNotAllowedError,
        EsisteOdonimoPostMethodNotAllowedErrorData,
        EsisteOdonimoPostUnprocessableEntityError,
        EsisteOdonimoPostUnprocessableEntityErrorData,
    )
    from .no_response_error import NoResponseError
    from .prognazaccgetpathparamop import (
        PrognazaccGetPathParamBadRequestError,
        PrognazaccGetPathParamBadRequestErrorData,
        PrognazaccGetPathParamInternalServerError,
        PrognazaccGetPathParamInternalServerErrorData,
        PrognazaccGetPathParamMethodNotAllowedError,
        PrognazaccGetPathParamMethodNotAllowedErrorData,
        PrognazaccGetPathParamNotFoundError,
        PrognazaccGetPathParamNotFoundErrorData,
        PrognazaccGetPathParamUnprocessableEntityError,
        PrognazaccGetPathParamUnprocessableEntityErrorData,
    )
    from .prognazaccgetqueryparamop import (
        PrognazaccGetQueryParamBadRequestError,
        PrognazaccGetQueryParamBadRequestErrorData,
        PrognazaccGetQueryParamInternalServerError,
        PrognazaccGetQueryParamInternalServerErrorData,
        PrognazaccGetQueryParamMethodNotAllowedError,
        PrognazaccGetQueryParamMethodNotAllowedErrorData,
        PrognazaccGetQueryParamNotFoundError,
        PrognazaccGetQueryParamNotFoundErrorData,
        PrognazaccGetQueryParamUnprocessableEntityError,
        PrognazaccGetQueryParamUnprocessableEntityErrorData,
    )
    from .prognazaccpostop import (
        PrognazaccPostBadRequestError,
        PrognazaccPostBadRequestErrorData,
        PrognazaccPostInternalServerError,
        PrognazaccPostInternalServerErrorData,
        PrognazaccPostMethodNotAllowedError,
        PrognazaccPostMethodNotAllowedErrorData,
        PrognazaccPostNotFoundError,
        PrognazaccPostNotFoundErrorData,
        PrognazaccPostUnprocessableEntityError,
        PrognazaccPostUnprocessableEntityErrorData,
    )
    from .prognazareagetpathparamop import (
        PrognazareaGetPathParamBadRequestError,
        PrognazareaGetPathParamBadRequestErrorData,
        PrognazareaGetPathParamInternalServerError,
        PrognazareaGetPathParamInternalServerErrorData,
        PrognazareaGetPathParamMethodNotAllowedError,
        PrognazareaGetPathParamMethodNotAllowedErrorData,
        PrognazareaGetPathParamNotFoundError,
        PrognazareaGetPathParamNotFoundErrorData,
        PrognazareaGetPathParamUnprocessableEntityError,
        PrognazareaGetPathParamUnprocessableEntityErrorData,
    )
    from .prognazareagetqueryparamop import (
        PrognazareaGetQueryParamBadRequestError,
        PrognazareaGetQueryParamBadRequestErrorData,
        PrognazareaGetQueryParamInternalServerError,
        PrognazareaGetQueryParamInternalServerErrorData,
        PrognazareaGetQueryParamMethodNotAllowedError,
        PrognazareaGetQueryParamMethodNotAllowedErrorData,
        PrognazareaGetQueryParamNotFoundError,
        PrognazareaGetQueryParamNotFoundErrorData,
        PrognazareaGetQueryParamUnprocessableEntityError,
        PrognazareaGetQueryParamUnprocessableEntityErrorData,
    )
    from .prognazareapostop import (
        PrognazareaPostBadRequestError,
        PrognazareaPostBadRequestErrorData,
        PrognazareaPostInternalServerError,
        PrognazareaPostInternalServerErrorData,
        PrognazareaPostMethodNotAllowedError,
        PrognazareaPostMethodNotAllowedErrorData,
        PrognazareaPostNotFoundError,
        PrognazareaPostNotFoundErrorData,
        PrognazareaPostUnprocessableEntityError,
        PrognazareaPostUnprocessableEntityErrorData,
    )
    from .responsevalidationerror import ResponseValidationError
    from .show_statusop import ServiceUnavailableError, ServiceUnavailableErrorData

__all__ = [
    "APIError",
    "AnncsuError",
    "ElencoAccessiGetPathParamBadRequestError",
    "ElencoAccessiGetPathParamBadRequestErrorData",
    "ElencoAccessiGetPathParamInternalServerError",
    "ElencoAccessiGetPathParamInternalServerErrorData",
    "ElencoAccessiGetPathParamMethodNotAllowedError",
    "ElencoAccessiGetPathParamMethodNotAllowedErrorData",
    "ElencoAccessiGetPathParamNotFoundError",
    "ElencoAccessiGetPathParamNotFoundErrorData",
    "ElencoAccessiGetPathParamUnprocessableEntityError",
    "ElencoAccessiGetPathParamUnprocessableEntityErrorData",
    "ElencoAccessiGetQueryParamBadRequestError",
    "ElencoAccessiGetQueryParamBadRequestErrorData",
    "ElencoAccessiGetQueryParamInternalServerError",
    "ElencoAccessiGetQueryParamInternalServerErrorData",
    "ElencoAccessiGetQueryParamMethodNotAllowedError",
    "ElencoAccessiGetQueryParamMethodNotAllowedErrorData",
    "ElencoAccessiGetQueryParamNotFoundError",
    "ElencoAccessiGetQueryParamNotFoundErrorData",
    "ElencoAccessiGetQueryParamUnprocessableEntityError",
    "ElencoAccessiGetQueryParamUnprocessableEntityErrorData",
    "ElencoAccessiPostBadRequestError",
    "ElencoAccessiPostBadRequestErrorData",
    "ElencoAccessiPostInternalServerError",
    "ElencoAccessiPostInternalServerErrorData",
    "ElencoAccessiPostMethodNotAllowedError",
    "ElencoAccessiPostMethodNotAllowedErrorData",
    "ElencoAccessiPostNotFoundError",
    "ElencoAccessiPostNotFoundErrorData",
    "ElencoAccessiPostUnprocessableEntityError",
    "ElencoAccessiPostUnprocessableEntityErrorData",
    "ElencoOdonimiGetPathParamBadRequestError",
    "ElencoOdonimiGetPathParamBadRequestErrorData",
    "ElencoOdonimiGetPathParamInternalServerError",
    "ElencoOdonimiGetPathParamInternalServerErrorData",
    "ElencoOdonimiGetPathParamMethodNotAllowedError",
    "ElencoOdonimiGetPathParamMethodNotAllowedErrorData",
    "ElencoOdonimiGetPathParamNotFoundError",
    "ElencoOdonimiGetPathParamNotFoundErrorData",
    "ElencoOdonimiGetPathParamUnprocessableEntityError",
    "ElencoOdonimiGetPathParamUnprocessableEntityErrorData",
    "ElencoOdonimiGetQueryParamBadRequestError",
    "ElencoOdonimiGetQueryParamBadRequestErrorData",
    "ElencoOdonimiGetQueryParamInternalServerError",
    "ElencoOdonimiGetQueryParamInternalServerErrorData",
    "ElencoOdonimiGetQueryParamMethodNotAllowedError",
    "ElencoOdonimiGetQueryParamMethodNotAllowedErrorData",
    "ElencoOdonimiGetQueryParamNotFoundError",
    "ElencoOdonimiGetQueryParamNotFoundErrorData",
    "ElencoOdonimiGetQueryParamUnprocessableEntityError",
    "ElencoOdonimiGetQueryParamUnprocessableEntityErrorData",
    "ElencoOdonimiPostBadRequestError",
    "ElencoOdonimiPostBadRequestErrorData",
    "ElencoOdonimiPostInternalServerError",
    "ElencoOdonimiPostInternalServerErrorData",
    "ElencoOdonimiPostMethodNotAllowedError",
    "ElencoOdonimiPostMethodNotAllowedErrorData",
    "ElencoOdonimiPostNotFoundError",
    "ElencoOdonimiPostNotFoundErrorData",
    "ElencoOdonimiPostUnprocessableEntityError",
    "ElencoOdonimiPostUnprocessableEntityErrorData",
    "ElencoaccessiprogGetPathParamBadRequestError",
    "ElencoaccessiprogGetPathParamBadRequestErrorData",
    "ElencoaccessiprogGetPathParamInternalServerError",
    "ElencoaccessiprogGetPathParamInternalServerErrorData",
    "ElencoaccessiprogGetPathParamMethodNotAllowedError",
    "ElencoaccessiprogGetPathParamMethodNotAllowedErrorData",
    "ElencoaccessiprogGetPathParamNotFoundError",
    "ElencoaccessiprogGetPathParamNotFoundErrorData",
    "ElencoaccessiprogGetPathParamUnprocessableEntityError",
    "ElencoaccessiprogGetPathParamUnprocessableEntityErrorData",
    "ElencoaccessiprogGetQueryParamBadRequestError",
    "ElencoaccessiprogGetQueryParamBadRequestErrorData",
    "ElencoaccessiprogGetQueryParamInternalServerError",
    "ElencoaccessiprogGetQueryParamInternalServerErrorData",
    "ElencoaccessiprogGetQueryParamMethodNotAllowedError",
    "ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData",
    "ElencoaccessiprogGetQueryParamNotFoundError",
    "ElencoaccessiprogGetQueryParamNotFoundErrorData",
    "ElencoaccessiprogGetQueryParamUnprocessableEntityError",
    "ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData",
    "ElencoaccessiprogPostBadRequestError",
    "ElencoaccessiprogPostBadRequestErrorData",
    "ElencoaccessiprogPostInternalServerError",
    "ElencoaccessiprogPostInternalServerErrorData",
    "ElencoaccessiprogPostMethodNotAllowedError",
    "ElencoaccessiprogPostMethodNotAllowedErrorData",
    "ElencoaccessiprogPostNotFoundError",
    "ElencoaccessiprogPostNotFoundErrorData",
    "ElencoaccessiprogPostUnprocessableEntityError",
    "ElencoaccessiprogPostUnprocessableEntityErrorData",
    "ElencoodonimiprogGetPathParamBadRequestError",
    "ElencoodonimiprogGetPathParamBadRequestErrorData",
    "ElencoodonimiprogGetPathParamInternalServerError",
    "ElencoodonimiprogGetPathParamInternalServerErrorData",
    "ElencoodonimiprogGetPathParamMethodNotAllowedError",
    "ElencoodonimiprogGetPathParamMethodNotAllowedErrorData",
    "ElencoodonimiprogGetPathParamNotFoundError",
    "ElencoodonimiprogGetPathParamNotFoundErrorData",
    "ElencoodonimiprogGetPathParamUnprocessableEntityError",
    "ElencoodonimiprogGetPathParamUnprocessableEntityErrorData",
    "ElencoodonimiprogGetQueryParamBadRequestError",
    "ElencoodonimiprogGetQueryParamBadRequestErrorData",
    "ElencoodonimiprogGetQueryParamInternalServerError",
    "ElencoodonimiprogGetQueryParamInternalServerErrorData",
    "ElencoodonimiprogGetQueryParamMethodNotAllowedError",
    "ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData",
    "ElencoodonimiprogGetQueryParamNotFoundError",
    "ElencoodonimiprogGetQueryParamNotFoundErrorData",
    "ElencoodonimiprogGetQueryParamUnprocessableEntityError",
    "ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData",
    "ElencoodonimiprogPostBadRequestError",
    "ElencoodonimiprogPostBadRequestErrorData",
    "ElencoodonimiprogPostInternalServerError",
    "ElencoodonimiprogPostInternalServerErrorData",
    "ElencoodonimiprogPostMethodNotAllowedError",
    "ElencoodonimiprogPostMethodNotAllowedErrorData",
    "ElencoodonimiprogPostNotFoundError",
    "ElencoodonimiprogPostNotFoundErrorData",
    "ElencoodonimiprogPostUnprocessableEntityError",
    "ElencoodonimiprogPostUnprocessableEntityErrorData",
    "EsisteAccessoGetPathParamBadRequestError",
    "EsisteAccessoGetPathParamBadRequestErrorData",
    "EsisteAccessoGetPathParamInternalServerError",
    "EsisteAccessoGetPathParamInternalServerErrorData",
    "EsisteAccessoGetPathParamMethodNotAllowedError",
    "EsisteAccessoGetPathParamMethodNotAllowedErrorData",
    "EsisteAccessoGetPathParamUnprocessableEntityError",
    "EsisteAccessoGetPathParamUnprocessableEntityErrorData",
    "EsisteAccessoGetQueryParamBadRequestError",
    "EsisteAccessoGetQueryParamBadRequestErrorData",
    "EsisteAccessoGetQueryParamInternalServerError",
    "EsisteAccessoGetQueryParamInternalServerErrorData",
    "EsisteAccessoGetQueryParamMethodNotAllowedError",
    "EsisteAccessoGetQueryParamMethodNotAllowedErrorData",
    "EsisteAccessoGetQueryParamUnprocessableEntityError",
    "EsisteAccessoGetQueryParamUnprocessableEntityErrorData",
    "EsisteAccessoPostBadRequestError",
    "EsisteAccessoPostBadRequestErrorData",
    "EsisteAccessoPostInternalServerError",
    "EsisteAccessoPostInternalServerErrorData",
    "EsisteAccessoPostMethodNotAllowedError",
    "EsisteAccessoPostMethodNotAllowedErrorData",
    "EsisteAccessoPostUnprocessableEntityError",
    "EsisteAccessoPostUnprocessableEntityErrorData",
    "EsisteOdonimoGetPathParamBadRequestError",
    "EsisteOdonimoGetPathParamBadRequestErrorData",
    "EsisteOdonimoGetPathParamInternalServerError",
    "EsisteOdonimoGetPathParamInternalServerErrorData",
    "EsisteOdonimoGetPathParamMethodNotAllowedError",
    "EsisteOdonimoGetPathParamMethodNotAllowedErrorData",
    "EsisteOdonimoGetPathParamUnprocessableEntityError",
    "EsisteOdonimoGetPathParamUnprocessableEntityErrorData",
    "EsisteOdonimoGetQueryParamBadRequestError",
    "EsisteOdonimoGetQueryParamBadRequestErrorData",
    "EsisteOdonimoGetQueryParamInternalServerError",
    "EsisteOdonimoGetQueryParamInternalServerErrorData",
    "EsisteOdonimoGetQueryParamMethodNotAllowedError",
    "EsisteOdonimoGetQueryParamMethodNotAllowedErrorData",
    "EsisteOdonimoGetQueryParamUnprocessableEntityError",
    "EsisteOdonimoGetQueryParamUnprocessableEntityErrorData",
    "EsisteOdonimoPostBadRequestError",
    "EsisteOdonimoPostBadRequestErrorData",
    "EsisteOdonimoPostInternalServerError",
    "EsisteOdonimoPostInternalServerErrorData",
    "EsisteOdonimoPostMethodNotAllowedError",
    "EsisteOdonimoPostMethodNotAllowedErrorData",
    "EsisteOdonimoPostUnprocessableEntityError",
    "EsisteOdonimoPostUnprocessableEntityErrorData",
    "NoResponseError",
    "PrognazaccGetPathParamBadRequestError",
    "PrognazaccGetPathParamBadRequestErrorData",
    "PrognazaccGetPathParamInternalServerError",
    "PrognazaccGetPathParamInternalServerErrorData",
    "PrognazaccGetPathParamMethodNotAllowedError",
    "PrognazaccGetPathParamMethodNotAllowedErrorData",
    "PrognazaccGetPathParamNotFoundError",
    "PrognazaccGetPathParamNotFoundErrorData",
    "PrognazaccGetPathParamUnprocessableEntityError",
    "PrognazaccGetPathParamUnprocessableEntityErrorData",
    "PrognazaccGetQueryParamBadRequestError",
    "PrognazaccGetQueryParamBadRequestErrorData",
    "PrognazaccGetQueryParamInternalServerError",
    "PrognazaccGetQueryParamInternalServerErrorData",
    "PrognazaccGetQueryParamMethodNotAllowedError",
    "PrognazaccGetQueryParamMethodNotAllowedErrorData",
    "PrognazaccGetQueryParamNotFoundError",
    "PrognazaccGetQueryParamNotFoundErrorData",
    "PrognazaccGetQueryParamUnprocessableEntityError",
    "PrognazaccGetQueryParamUnprocessableEntityErrorData",
    "PrognazaccPostBadRequestError",
    "PrognazaccPostBadRequestErrorData",
    "PrognazaccPostInternalServerError",
    "PrognazaccPostInternalServerErrorData",
    "PrognazaccPostMethodNotAllowedError",
    "PrognazaccPostMethodNotAllowedErrorData",
    "PrognazaccPostNotFoundError",
    "PrognazaccPostNotFoundErrorData",
    "PrognazaccPostUnprocessableEntityError",
    "PrognazaccPostUnprocessableEntityErrorData",
    "PrognazareaGetPathParamBadRequestError",
    "PrognazareaGetPathParamBadRequestErrorData",
    "PrognazareaGetPathParamInternalServerError",
    "PrognazareaGetPathParamInternalServerErrorData",
    "PrognazareaGetPathParamMethodNotAllowedError",
    "PrognazareaGetPathParamMethodNotAllowedErrorData",
    "PrognazareaGetPathParamNotFoundError",
    "PrognazareaGetPathParamNotFoundErrorData",
    "PrognazareaGetPathParamUnprocessableEntityError",
    "PrognazareaGetPathParamUnprocessableEntityErrorData",
    "PrognazareaGetQueryParamBadRequestError",
    "PrognazareaGetQueryParamBadRequestErrorData",
    "PrognazareaGetQueryParamInternalServerError",
    "PrognazareaGetQueryParamInternalServerErrorData",
    "PrognazareaGetQueryParamMethodNotAllowedError",
    "PrognazareaGetQueryParamMethodNotAllowedErrorData",
    "PrognazareaGetQueryParamNotFoundError",
    "PrognazareaGetQueryParamNotFoundErrorData",
    "PrognazareaGetQueryParamUnprocessableEntityError",
    "PrognazareaGetQueryParamUnprocessableEntityErrorData",
    "PrognazareaPostBadRequestError",
    "PrognazareaPostBadRequestErrorData",
    "PrognazareaPostInternalServerError",
    "PrognazareaPostInternalServerErrorData",
    "PrognazareaPostMethodNotAllowedError",
    "PrognazareaPostMethodNotAllowedErrorData",
    "PrognazareaPostNotFoundError",
    "PrognazareaPostNotFoundErrorData",
    "PrognazareaPostUnprocessableEntityError",
    "PrognazareaPostUnprocessableEntityErrorData",
    "ResponseValidationError",
    "ServiceUnavailableError",
    "ServiceUnavailableErrorData",
]

_dynamic_imports: dict[str, str] = {
    "AnncsuError": ".anncsuerror",
    "APIError": ".apierror",
    "ElencoAccessiGetPathParamBadRequestError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamBadRequestErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamInternalServerError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamInternalServerErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamMethodNotAllowedError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamMethodNotAllowedErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamNotFoundError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamNotFoundErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamUnprocessableEntityError": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetPathParamUnprocessableEntityErrorData": ".elencoaccessigetpathparamop",
    "ElencoAccessiGetQueryParamBadRequestError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamBadRequestErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamInternalServerError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamInternalServerErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamMethodNotAllowedError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamMethodNotAllowedErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamNotFoundError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamNotFoundErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamUnprocessableEntityError": ".elencoaccessigetqueryparamop",
    "ElencoAccessiGetQueryParamUnprocessableEntityErrorData": ".elencoaccessigetqueryparamop",
    "ElencoAccessiPostBadRequestError": ".elencoaccessipostop",
    "ElencoAccessiPostBadRequestErrorData": ".elencoaccessipostop",
    "ElencoAccessiPostInternalServerError": ".elencoaccessipostop",
    "ElencoAccessiPostInternalServerErrorData": ".elencoaccessipostop",
    "ElencoAccessiPostMethodNotAllowedError": ".elencoaccessipostop",
    "ElencoAccessiPostMethodNotAllowedErrorData": ".elencoaccessipostop",
    "ElencoAccessiPostNotFoundError": ".elencoaccessipostop",
    "ElencoAccessiPostNotFoundErrorData": ".elencoaccessipostop",
    "ElencoAccessiPostUnprocessableEntityError": ".elencoaccessipostop",
    "ElencoAccessiPostUnprocessableEntityErrorData": ".elencoaccessipostop",
    "ElencoaccessiprogGetPathParamBadRequestError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamBadRequestErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamInternalServerError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamInternalServerErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamMethodNotAllowedError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamMethodNotAllowedErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamNotFoundError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamNotFoundErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamUnprocessableEntityError": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetPathParamUnprocessableEntityErrorData": ".elencoaccessiproggetpathparamop",
    "ElencoaccessiprogGetQueryParamBadRequestError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamBadRequestErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamInternalServerError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamInternalServerErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamMethodNotAllowedError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamMethodNotAllowedErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamNotFoundError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamNotFoundErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamUnprocessableEntityError": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogGetQueryParamUnprocessableEntityErrorData": ".elencoaccessiproggetqueryparamop",
    "ElencoaccessiprogPostBadRequestError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostBadRequestErrorData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostInternalServerError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostInternalServerErrorData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostMethodNotAllowedError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostMethodNotAllowedErrorData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostNotFoundError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostNotFoundErrorData": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostUnprocessableEntityError": ".elencoaccessiprogpostop",
    "ElencoaccessiprogPostUnprocessableEntityErrorData": ".elencoaccessiprogpostop",
    "ElencoOdonimiGetPathParamBadRequestError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamBadRequestErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamInternalServerError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamInternalServerErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamMethodNotAllowedError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamMethodNotAllowedErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamNotFoundError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamNotFoundErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamUnprocessableEntityError": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetPathParamUnprocessableEntityErrorData": ".elencoodonimigetpathparamop",
    "ElencoOdonimiGetQueryParamBadRequestError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamBadRequestErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamInternalServerError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamInternalServerErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamMethodNotAllowedError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamMethodNotAllowedErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamNotFoundError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamNotFoundErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamUnprocessableEntityError": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiGetQueryParamUnprocessableEntityErrorData": ".elencoodonimigetqueryparamop",
    "ElencoOdonimiPostBadRequestError": ".elencoodonimipostop",
    "ElencoOdonimiPostBadRequestErrorData": ".elencoodonimipostop",
    "ElencoOdonimiPostInternalServerError": ".elencoodonimipostop",
    "ElencoOdonimiPostInternalServerErrorData": ".elencoodonimipostop",
    "ElencoOdonimiPostMethodNotAllowedError": ".elencoodonimipostop",
    "ElencoOdonimiPostMethodNotAllowedErrorData": ".elencoodonimipostop",
    "ElencoOdonimiPostNotFoundError": ".elencoodonimipostop",
    "ElencoOdonimiPostNotFoundErrorData": ".elencoodonimipostop",
    "ElencoOdonimiPostUnprocessableEntityError": ".elencoodonimipostop",
    "ElencoOdonimiPostUnprocessableEntityErrorData": ".elencoodonimipostop",
    "ElencoodonimiprogGetPathParamBadRequestError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamBadRequestErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamInternalServerError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamInternalServerErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamMethodNotAllowedError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamMethodNotAllowedErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamNotFoundError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamNotFoundErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamUnprocessableEntityError": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetPathParamUnprocessableEntityErrorData": ".elencoodonimiproggetpathparamop",
    "ElencoodonimiprogGetQueryParamBadRequestError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamBadRequestErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamInternalServerError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamInternalServerErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamMethodNotAllowedError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamMethodNotAllowedErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamNotFoundError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamNotFoundErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamUnprocessableEntityError": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogGetQueryParamUnprocessableEntityErrorData": ".elencoodonimiproggetqueryparamop",
    "ElencoodonimiprogPostBadRequestError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostBadRequestErrorData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostInternalServerError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostInternalServerErrorData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostMethodNotAllowedError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostMethodNotAllowedErrorData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostNotFoundError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostNotFoundErrorData": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostUnprocessableEntityError": ".elencoodonimiprogpostop",
    "ElencoodonimiprogPostUnprocessableEntityErrorData": ".elencoodonimiprogpostop",
    "EsisteAccessoGetPathParamBadRequestError": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamBadRequestErrorData": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamInternalServerError": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamInternalServerErrorData": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamMethodNotAllowedError": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamMethodNotAllowedErrorData": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamUnprocessableEntityError": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetPathParamUnprocessableEntityErrorData": ".esisteaccessogetpathparamop",
    "EsisteAccessoGetQueryParamBadRequestError": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamBadRequestErrorData": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamInternalServerError": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamInternalServerErrorData": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamMethodNotAllowedError": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamMethodNotAllowedErrorData": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamUnprocessableEntityError": ".esisteaccessogetqueryparamop",
    "EsisteAccessoGetQueryParamUnprocessableEntityErrorData": ".esisteaccessogetqueryparamop",
    "EsisteAccessoPostBadRequestError": ".esisteaccessopostop",
    "EsisteAccessoPostBadRequestErrorData": ".esisteaccessopostop",
    "EsisteAccessoPostInternalServerError": ".esisteaccessopostop",
    "EsisteAccessoPostInternalServerErrorData": ".esisteaccessopostop",
    "EsisteAccessoPostMethodNotAllowedError": ".esisteaccessopostop",
    "EsisteAccessoPostMethodNotAllowedErrorData": ".esisteaccessopostop",
    "EsisteAccessoPostUnprocessableEntityError": ".esisteaccessopostop",
    "EsisteAccessoPostUnprocessableEntityErrorData": ".esisteaccessopostop",
    "EsisteOdonimoGetPathParamBadRequestError": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamBadRequestErrorData": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamInternalServerError": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamInternalServerErrorData": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamMethodNotAllowedError": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamMethodNotAllowedErrorData": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamUnprocessableEntityError": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetPathParamUnprocessableEntityErrorData": ".esisteodonimogetpathparamop",
    "EsisteOdonimoGetQueryParamBadRequestError": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamBadRequestErrorData": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamInternalServerError": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamInternalServerErrorData": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamMethodNotAllowedError": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamMethodNotAllowedErrorData": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamUnprocessableEntityError": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoGetQueryParamUnprocessableEntityErrorData": ".esisteodonimogetqueryparamop",
    "EsisteOdonimoPostBadRequestError": ".esisteodonimopostop",
    "EsisteOdonimoPostBadRequestErrorData": ".esisteodonimopostop",
    "EsisteOdonimoPostInternalServerError": ".esisteodonimopostop",
    "EsisteOdonimoPostInternalServerErrorData": ".esisteodonimopostop",
    "EsisteOdonimoPostMethodNotAllowedError": ".esisteodonimopostop",
    "EsisteOdonimoPostMethodNotAllowedErrorData": ".esisteodonimopostop",
    "EsisteOdonimoPostUnprocessableEntityError": ".esisteodonimopostop",
    "EsisteOdonimoPostUnprocessableEntityErrorData": ".esisteodonimopostop",
    "NoResponseError": ".no_response_error",
    "PrognazaccGetPathParamBadRequestError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamBadRequestErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamInternalServerError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamInternalServerErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamMethodNotAllowedError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamMethodNotAllowedErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamNotFoundError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamNotFoundErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamUnprocessableEntityError": ".prognazaccgetpathparamop",
    "PrognazaccGetPathParamUnprocessableEntityErrorData": ".prognazaccgetpathparamop",
    "PrognazaccGetQueryParamBadRequestError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamBadRequestErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamInternalServerError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamInternalServerErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamMethodNotAllowedError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamMethodNotAllowedErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamNotFoundError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamNotFoundErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamUnprocessableEntityError": ".prognazaccgetqueryparamop",
    "PrognazaccGetQueryParamUnprocessableEntityErrorData": ".prognazaccgetqueryparamop",
    "PrognazaccPostBadRequestError": ".prognazaccpostop",
    "PrognazaccPostBadRequestErrorData": ".prognazaccpostop",
    "PrognazaccPostInternalServerError": ".prognazaccpostop",
    "PrognazaccPostInternalServerErrorData": ".prognazaccpostop",
    "PrognazaccPostMethodNotAllowedError": ".prognazaccpostop",
    "PrognazaccPostMethodNotAllowedErrorData": ".prognazaccpostop",
    "PrognazaccPostNotFoundError": ".prognazaccpostop",
    "PrognazaccPostNotFoundErrorData": ".prognazaccpostop",
    "PrognazaccPostUnprocessableEntityError": ".prognazaccpostop",
    "PrognazaccPostUnprocessableEntityErrorData": ".prognazaccpostop",
    "PrognazareaGetPathParamBadRequestError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamBadRequestErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamInternalServerError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamInternalServerErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamMethodNotAllowedError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamMethodNotAllowedErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamNotFoundError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamNotFoundErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamUnprocessableEntityError": ".prognazareagetpathparamop",
    "PrognazareaGetPathParamUnprocessableEntityErrorData": ".prognazareagetpathparamop",
    "PrognazareaGetQueryParamBadRequestError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamBadRequestErrorData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamInternalServerError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamInternalServerErrorData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamMethodNotAllowedError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamMethodNotAllowedErrorData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamNotFoundError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamNotFoundErrorData": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamUnprocessableEntityError": ".prognazareagetqueryparamop",
    "PrognazareaGetQueryParamUnprocessableEntityErrorData": ".prognazareagetqueryparamop",
    "PrognazareaPostBadRequestError": ".prognazareapostop",
    "PrognazareaPostBadRequestErrorData": ".prognazareapostop",
    "PrognazareaPostInternalServerError": ".prognazareapostop",
    "PrognazareaPostInternalServerErrorData": ".prognazareapostop",
    "PrognazareaPostMethodNotAllowedError": ".prognazareapostop",
    "PrognazareaPostMethodNotAllowedErrorData": ".prognazareapostop",
    "PrognazareaPostNotFoundError": ".prognazareapostop",
    "PrognazareaPostNotFoundErrorData": ".prognazareapostop",
    "PrognazareaPostUnprocessableEntityError": ".prognazareapostop",
    "PrognazareaPostUnprocessableEntityErrorData": ".prognazareapostop",
    "ResponseValidationError": ".responsevalidationerror",
    "ServiceUnavailableError": ".show_statusop",
    "ServiceUnavailableErrorData": ".show_statusop",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)



"""
Create a client assertion JWT for PDND authentication.

This script generates a signed JWT client assertion required for PDND (Piattaforma Digitale Nazionale Dati)
authentication. The JWT is signed with an RSA private key and includes all required claims.

Usage:
    python create_client_assertion.py \
        --kid <key_id> \
        --alg RS256 \
        --typ JWT \
        --issuer <client_id> \
        --subject <client_id> \
        --audience <audience_url> \
        --purpose-id <purpose_id> \
        --key-path <path_to_private_key>

    Or using the modern CLI:

    python create_client_assertion.py create \
        --kid <key_id> \
        --issuer <client_id> \
        --subject <client_id> \
        --audience <audience_url> \
        --purpose-id <purpose_id> \
        --key-path <path_to_private_key>

Requirements:
    - Python 3.12+
    - authlib>=1.3.0
    - typer>=0.15.0
    - pydantic>=2.11.2
"""

import datetime
import os
import uuid
from pathlib import Path
from typing import Annotated

import typer
from authlib.jose import jwt
from pydantic import BaseModel, Field, field_validator
from rich.console import Console

# Initialize Typer app and Rich console
app = typer.Typer(
    help="Generate client assertion JWTs for PDND authentication",
    no_args_is_help=True,
)
console = Console()


class JWTConfig(BaseModel):
    """Configuration for JWT client assertion generation with validation."""

    kid: Annotated[
        str,
        Field(
            description="Key ID (kid) header parameter - identifies which key was used",
            min_length=1,
        ),
    ]
    alg: Annotated[
        str,
        Field(
            description="Algorithm for signing the JWT",
            pattern="^RS256$",
        ),
    ] = "RS256"
    typ: Annotated[
        str,
        Field(
            description="Token type",
            pattern="^JWT$",
        ),
    ] = "JWT"
    issuer: Annotated[
        str,
        Field(
            description="Issuer (iss) - typically your client_id from PDND",
            min_length=1,
        ),
    ]
    subject: Annotated[
        str,
        Field(
            description="Subject (sub) - typically your client_id from PDND",
            min_length=1,
        ),
    ]
    audience: Annotated[
        str,
        Field(
            description="Audience (aud) - the PDND token endpoint URL",
            pattern="^https://.*",
        ),
    ]
    purpose_id: Annotated[
        str,
        Field(
            description="Purpose ID for the PDND request",
            min_length=1,
        ),
    ]
    key_path: Annotated[
        Path,
        Field(description="Path to the RSA private key file (PEM format)"),
    ]
    validity_minutes: Annotated[
        int,
        Field(
            description="JWT validity period in minutes",
            gt=0,
            le=43200,  # Max 30 days
        ),
    ] = 43200

    @field_validator("key_path")
    @classmethod
    def validate_key_path(cls, v: Path) -> Path:
        """Validate that the key file exists and is readable."""
        if not v.exists():
            raise ValueError(f"Key file not found: {v}")
        if not v.is_file():
            raise ValueError(f"Key path is not a file: {v}")
        return v

    @field_validator("audience")
    @classmethod
    def validate_audience(cls, v: str) -> str:
        """Validate audience URL format."""
        if not v.startswith("https://"):
            raise ValueError("Audience must be an HTTPS URL")
        return v


def read_private_key(key_path: Path) -> bytes:
    """
    Read the RSA private key from a file.

    Args:
        key_path: Path to the private key file (PEM format)

    Returns:
        bytes: The private key content

    Raises:
        FileNotFoundError: If the key file doesn't exist
        PermissionError: If the key file is not readable
    """
    try:
        return key_path.read_bytes()
    except FileNotFoundError:
        console.print(f"[red]Error: Key file not found: {key_path}[/red]")
        raise typer.Exit(code=1) from None
    except PermissionError:
        console.print(
            f"[red]Error: Permission denied reading key file: {key_path}[/red]"
        )
        raise typer.Exit(code=1) from None


def generate_jwt(config: JWTConfig) -> str:
    """
    Generate a JWT client assertion with the given configuration.

    Args:
        config: JWT configuration validated by Pydantic

    Returns:
        str: The generated JWT token

    Raises:
        Exception: If JWT generation fails
    """
    # Generate timestamps
    issued = datetime.datetime.now(datetime.UTC)
    delta = datetime.timedelta(minutes=config.validity_minutes)
    expire_in = issued + delta
    jti = uuid.uuid4()

    # JWT header
    header = {
        "kid": config.kid,
        "alg": config.alg,
        "typ": config.typ,
    }

    # JWT payload
    payload = {
        "iss": config.issuer,
        "sub": config.subject,
        "aud": config.audience,
        "purposeId": config.purpose_id,
        "jti": str(jti),
        "iat": int(issued.timestamp()),
        "exp": int(expire_in.timestamp()),
    }

    # Load the private key
    rsa_key = read_private_key(config.key_path)

    try:
        # Encode the JWT using authlib
        client_assertion = jwt.encode(header, payload, rsa_key)

        # authlib returns bytes, decode to string
        if isinstance(client_assertion, bytes):
            client_assertion = client_assertion.decode("utf-8")

        return client_assertion
    except Exception as e:
        console.print(f"[red]Error generating JWT: {e}[/red]")
        raise typer.Exit(code=1) from None


@app.command()
def create(
    kid: Annotated[
        str,
        typer.Option(
            "--kid",
            help="Key ID (kid) header parameter - identifies which key was used",
            show_default=False,
            metavar="KEY_ID",
            rich_help_panel="Required JWT Header Parameters",
        ),
    ],
    issuer: Annotated[
        str,
        typer.Option(
            "--issuer",
            help="Issuer (iss) - typically your client_id from PDND. Example: 'a1b2c3d4-e5f6-7890-abcd-ef1234567890'",
            show_default=False,
            metavar="CLIENT_ID",
            rich_help_panel="Required JWT Claims",
        ),
    ],
    subject: Annotated[
        str,
        typer.Option(
            "--subject",
            help="Subject (sub) - typically your client_id from PDND. Example: 'a1b2c3d4-e5f6-7890-abcd-ef1234567890'",
            show_default=False,
            metavar="CLIENT_ID",
            rich_help_panel="Required JWT Claims",
        ),
    ],
    audience: Annotated[
        str,
        typer.Option(
            "--audience",
            help="Audience (aud) - the PDND token endpoint URL. Example: 'https://auth.interop.pagopa.it/token.oauth2'",
            show_default=False,
            metavar="URL",
            rich_help_panel="Required JWT Claims",
        ),
    ],
    purpose_id: Annotated[
        str,
        typer.Option(
            "--purpose-id",
            help="Purpose ID for the PDND request. Example: '12345678-90ab-cdef-1234-567890abcdef'",
            show_default=False,
            metavar="PURPOSE_ID",
            rich_help_panel="Required JWT Claims",
        ),
    ],
    key_path: Annotated[
        Path,
        typer.Option(
            "--key-path",
            help="Path to the RSA private key file (PEM format). Example: './private_key.pem'",
            exists=True,
            file_okay=True,
            dir_okay=False,
            readable=True,
            show_default=False,
            metavar="PATH",
            rich_help_panel="Required JWT Signing",
        ),
    ],
    alg: Annotated[
        str,
        typer.Option(
            "--alg",
            help="Algorithm for signing the JWT (only RS256 supported)",
            metavar="ALGORITHM",
            rich_help_panel="Optional JWT Parameters",
        ),
    ] = "RS256",
    typ: Annotated[
        str,
        typer.Option(
            "--typ",
            help="Token type (should be JWT)",
            metavar="TYPE",
            rich_help_panel="Optional JWT Parameters",
        ),
    ] = "JWT",
    validity_minutes: Annotated[
        int,
        typer.Option(
            "--validity-minutes",
            help="JWT validity period in minutes. Examples: 1440 (24 hours), 10080 (7 days), 43200 (30 days max)",
            min=1,
            max=43200,
            metavar="MINUTES",
            rich_help_panel="Optional JWT Parameters",
        ),
    ] = 43200,
    clear_screen: Annotated[
        bool,
        typer.Option(
            "--clear/--no-clear",
            help="Clear the terminal screen before output",
            rich_help_panel="Display Options",
        ),
    ] = True,
) -> None:
    """
    Generate a client assertion JWT for PDND authentication.

    This command creates a signed JWT token that can be used for PDND
    (Piattaforma Digitale Nazionale Dati) authentication.

    Example:

        python create_client_assertion.py create \\
            --kid "my-key-id" \\
            --issuer "my-client-id" \\
            --subject "my-client-id" \\
            --audience "https://auth.interop.pagopa.it/token.oauth2" \\
            --purpose-id "my-purpose-id" \\
            --key-path ./private_key.pem
    """
    try:
        # Create and validate configuration
        config = JWTConfig(
            kid=kid,
            alg=alg,
            typ=typ,
            issuer=issuer,
            subject=subject,
            audience=audience,
            purpose_id=purpose_id,
            key_path=key_path,
            validity_minutes=validity_minutes,
        )

        # Generate JWT
        token = generate_jwt(config)

        # Clear screen if requested
        if clear_screen:
            os.system("clear")

        # Output the token
        console.print(token)

    except ValueError as e:
        console.print(f"[red]Validation error: {e}[/red]")
        raise typer.Exit(code=1) from None
    except Exception as e:
        console.print(f"[red]Unexpected error: {e}[/red]")
        raise typer.Exit(code=1) from None


if __name__ == "__main__":
    app()



"""Tests for custom validators."""

import pytest
from pydantic import ValidationError

from anncsu.common.validation import base64_validator, belfiore_code_validator


class TestBase64Validator:
    """Tests for base64_validator function."""

    def test_valid_base64(self):
        """Test that valid base64 strings pass validation."""
        valid_strings = [
            "VklBIFJPTUE=",  # "VIA ROMA"
            "SGVsbG8gV29ybGQ=",  # "Hello World"
            "dGVzdA==",  # "test"
            "",  # Empty string is valid base64
        ]

        for s in valid_strings:
            result = base64_validator(s)
            assert result == s

    def test_invalid_base64(self):
        """Test that invalid base64 strings raise ValueError."""
        invalid_strings = [
            "Not valid base64!",
            "!!!",
            "VklBIFJPTUE",  # Missing padding
        ]

        for s in invalid_strings:
            with pytest.raises(ValueError, match="Invalid base64"):
                base64_validator(s)

    def test_non_string_input(self):
        """Test that non-string inputs raise ValueError."""
        with pytest.raises(ValueError, match="must be a string"):
            base64_validator(123)

        with pytest.raises(ValueError, match="must be a string"):
            base64_validator(None)


class TestBelfioreCodeValidator:
    """Tests for belfiore_code_validator function."""

    def test_valid_belfiore_codes(self):
        """Test that valid Belfiore codes pass validation."""
        valid_codes = [
            "H501",  # Rome
            "F205",  # Milan
            "A794",  # Bologna
            "Z999",  # Valid format
        ]

        for code in valid_codes:
            result = belfiore_code_validator(code)
            assert result == code

    def test_invalid_belfiore_codes(self):
        """Test that invalid Belfiore codes raise ValueError."""
        invalid_codes = [
            "h501",  # Lowercase letter
            "H50",  # Too short
            "H5011",  # Too long
            "1501",  # Starts with digit
            "HH01",  # Two letters
            "H5O1",  # Letter instead of digit
            "",  # Empty
            "H 501",  # Space
        ]

        for code in invalid_codes:
            with pytest.raises(ValueError, match="Invalid Belfiore code"):
                belfiore_code_validator(code)

    def test_non_string_input(self):
        """Test that non-string inputs raise ValueError."""
        with pytest.raises(ValueError, match="must be a string"):
            belfiore_code_validator(123)

        with pytest.raises(ValueError, match="must be a string"):
            belfiore_code_validator(None)


class TestValidatorsIntegration:
    """Integration tests for validators with Pydantic models."""

    def test_validators_in_pydantic_model(self):
        """Test that validators work correctly when used in Pydantic models."""
        from anncsu.common.validation.examples import (
            EsisteOdonimoGetQueryParamRequestValidated,
        )

        # Valid data
        valid_request = EsisteOdonimoGetQueryParamRequestValidated(
            codcom="H501", denom="VklBIFJPTUE="
        )
        assert valid_request.codcom == "H501"
        assert valid_request.denom == "VklBIFJPTUE="

    def test_invalid_belfiore_in_model(self):
        """Test that invalid Belfiore code raises ValidationError in model."""
        from anncsu.common.validation.examples import (
            EsisteOdonimoGetQueryParamRequestValidated,
        )

        with pytest.raises(ValidationError) as exc_info:
            EsisteOdonimoGetQueryParamRequestValidated(
                codcom="INVALID", denom="VklBIFJPTUE="
            )

        errors = exc_info.value.errors()
        assert len(errors) >= 1
        assert errors[0]["loc"] == ("codcom",)
        # Either Field constraint (max_length) or custom validator will catch this
        error_msg = str(errors[0]["msg"])
        assert (
            "at most 4 characters" in error_msg or "Invalid Belfiore code" in error_msg
        )

    def test_invalid_base64_in_model(self):
        """Test that invalid base64 raises ValidationError in model."""
        from anncsu.common.validation.examples import (
            EsisteOdonimoGetQueryParamRequestValidated,
        )

        with pytest.raises(ValidationError) as exc_info:
            EsisteOdonimoGetQueryParamRequestValidated(
                codcom="H501", denom="Not valid base64!"
            )

        errors = exc_info.value.errors()
        assert len(errors) == 1
        assert errors[0]["loc"] == ("denom",)
        assert "Invalid base64" in str(errors[0]["msg"])

    def test_field_constraints(self):
        """Test that Pydantic Field constraints are enforced."""
        from anncsu.common.validation.examples import (
            EsisteOdonimoGetQueryParamRequestValidated,
        )

        # Test min_length constraint on denom
        with pytest.raises(ValidationError) as exc_info:
            EsisteOdonimoGetQueryParamRequestValidated(codcom="H501", denom="")

        errors = exc_info.value.errors()
        assert any("at least 1 character" in str(e["msg"]) for e in errors)

        # Test pattern constraint on codcom
        with pytest.raises(ValidationError) as exc_info:
            EsisteOdonimoGetQueryParamRequestValidated(
                codcom="abc", denom="VklBIFJPTUE="
            )

        errors = exc_info.value.errors()
        assert len(errors) > 0



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from anncsu.common.errors import AnncsuBaseError as AnncsuError
from anncsu.common.types import BaseModel
import httpx
from typing import Optional


class EsisteOdonimoGetQueryParamInternalServerErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class EsisteOdonimoGetQueryParamInternalServerError(AnncsuError):
    r"""Internal Server Error"""

    data: EsisteOdonimoGetQueryParamInternalServerErrorData

    def __init__(
        self,
        data: EsisteOdonimoGetQueryParamInternalServerErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class EsisteOdonimoGetQueryParamUnprocessableEntityErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class EsisteOdonimoGetQueryParamUnprocessableEntityError(AnncsuError):
    r"""Unprocessable Entity - error in json"""

    data: EsisteOdonimoGetQueryParamUnprocessableEntityErrorData

    def __init__(
        self,
        data: EsisteOdonimoGetQueryParamUnprocessableEntityErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class EsisteOdonimoGetQueryParamMethodNotAllowedErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class EsisteOdonimoGetQueryParamMethodNotAllowedError(AnncsuError):
    r"""Method Not Allowed"""

    data: EsisteOdonimoGetQueryParamMethodNotAllowedErrorData

    def __init__(
        self,
        data: EsisteOdonimoGetQueryParamMethodNotAllowedErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data


class EsisteOdonimoGetQueryParamBadRequestErrorData(BaseModel):
    title: Optional[str] = None

    detail: Optional[str] = None


class EsisteOdonimoGetQueryParamBadRequestError(AnncsuError):
    r"""Bad Request"""

    data: EsisteOdonimoGetQueryParamBadRequestErrorData

    def __init__(
        self,
        data: EsisteOdonimoGetQueryParamBadRequestErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        self.data = data



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from anncsu.pa import errors, models
from anncsu.common import utils
from anncsu.common.hooks import HookContext
from anncsu.common.types import OptionalNullable, UNSET
from anncsu.common.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, Mapping, Optional


class JSONPost(BaseSDK):
    r"""Servizio con valori di input in file JSON sottomesso POST"""

    def esiste_odonimo_post(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denom: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.EsisteOdonimoPostResponse:
        r"""Ritorna un valore boolean dell'esistenza dell'odonimo in ANNCSU

        Ritorna un valore boolean dell'esistenza dell'odonimo in ANNCSU

        :param req:
        :param codcom:
        :param denom:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.EsisteOdonimoPostRequest(
            req=req,
            codcom=codcom,
            denom=denom,
        )

        req = self._build_request(
            method="POST",
            path="/esisteodonimo",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.EsisteOdonimoPostRequest
            ),
            timeout_ms=timeout_ms,
            security=self.sdk_configuration.security,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="esisteOdonimoPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.EsisteOdonimoPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteOdonimoPostBadRequestErrorData, http_res
            )
            raise errors.EsisteOdonimoPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteOdonimoPostMethodNotAllowedErrorData, http_res
            )
            raise errors.EsisteOdonimoPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteOdonimoPostUnprocessableEntityErrorData, http_res
            )
            raise errors.EsisteOdonimoPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteOdonimoPostInternalServerErrorData, http_res
            )
            raise errors.EsisteOdonimoPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def esiste_odonimo_post_async(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denom: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.EsisteOdonimoPostResponse:
        r"""Ritorna un valore boolean dell'esistenza dell'odonimo in ANNCSU

        Ritorna un valore boolean dell'esistenza dell'odonimo in ANNCSU

        :param req:
        :param codcom:
        :param denom:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.EsisteOdonimoPostRequest(
            req=req,
            codcom=codcom,
            denom=denom,
        )

        req = self._build_request_async(
            method="POST",
            path="/esisteodonimo",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.EsisteOdonimoPostRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="esisteOdonimoPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.EsisteOdonimoPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteOdonimoPostBadRequestErrorData, http_res
            )
            raise errors.EsisteOdonimoPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteOdonimoPostMethodNotAllowedErrorData, http_res
            )
            raise errors.EsisteOdonimoPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteOdonimoPostUnprocessableEntityErrorData, http_res
            )
            raise errors.EsisteOdonimoPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteOdonimoPostInternalServerErrorData, http_res
            )
            raise errors.EsisteOdonimoPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def esiste_accesso_post(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denom: Optional[str] = None,
        accesso: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.EsisteAccessoPostResponse:
        r"""Ritorna un valore boolean dell'esistenza dell'accesso in ANNCSU

        Ritorna un valore boolean dell'esistenza dell'accesso in ANNCSU

        :param req:
        :param codcom:
        :param denom:
        :param accesso:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.EsisteAccessoPostRequest(
            req=req,
            codcom=codcom,
            denom=denom,
            accesso=accesso,
        )

        req = self._build_request(
            method="POST",
            path="/esisteaccesso",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.EsisteAccessoPostRequest
            ),
            timeout_ms=timeout_ms,
            security=self.sdk_configuration.security,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="esisteAccessoPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.EsisteAccessoPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteAccessoPostBadRequestErrorData, http_res
            )
            raise errors.EsisteAccessoPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteAccessoPostMethodNotAllowedErrorData, http_res
            )
            raise errors.EsisteAccessoPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteAccessoPostUnprocessableEntityErrorData, http_res
            )
            raise errors.EsisteAccessoPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteAccessoPostInternalServerErrorData, http_res
            )
            raise errors.EsisteAccessoPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def esiste_accesso_post_async(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denom: Optional[str] = None,
        accesso: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.EsisteAccessoPostResponse:
        r"""Ritorna un valore boolean dell'esistenza dell'accesso in ANNCSU

        Ritorna un valore boolean dell'esistenza dell'accesso in ANNCSU

        :param req:
        :param codcom:
        :param denom:
        :param accesso:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.EsisteAccessoPostRequest(
            req=req,
            codcom=codcom,
            denom=denom,
            accesso=accesso,
        )

        req = self._build_request_async(
            method="POST",
            path="/esisteaccesso",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.EsisteAccessoPostRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="esisteAccessoPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.EsisteAccessoPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteAccessoPostBadRequestErrorData, http_res
            )
            raise errors.EsisteAccessoPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteAccessoPostMethodNotAllowedErrorData, http_res
            )
            raise errors.EsisteAccessoPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteAccessoPostUnprocessableEntityErrorData, http_res
            )
            raise errors.EsisteAccessoPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.EsisteAccessoPostInternalServerErrorData, http_res
            )
            raise errors.EsisteAccessoPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def elenco_odonimi_post(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denomparz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ElencoOdonimiPostResponse:
        r"""Ritorna un elenco di odonimi presenti in ANNCSU

        Ritorna un elenco di odonimi presenti in ANNCSU

        :param req:
        :param codcom:
        :param denomparz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ElencoOdonimiPostRequest(
            req=req,
            codcom=codcom,
            denomparz=denomparz,
        )

        req = self._build_request(
            method="POST",
            path="/elencoodonimi",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ElencoOdonimiPostRequest
            ),
            timeout_ms=timeout_ms,
            security=self.sdk_configuration.security,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="elencoOdonimiPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.ElencoOdonimiPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostBadRequestErrorData, http_res
            )
            raise errors.ElencoOdonimiPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostNotFoundErrorData, http_res
            )
            raise errors.ElencoOdonimiPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostMethodNotAllowedErrorData, http_res
            )
            raise errors.ElencoOdonimiPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostUnprocessableEntityErrorData, http_res
            )
            raise errors.ElencoOdonimiPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostInternalServerErrorData, http_res
            )
            raise errors.ElencoOdonimiPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def elenco_odonimi_post_async(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denomparz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ElencoOdonimiPostResponse:
        r"""Ritorna un elenco di odonimi presenti in ANNCSU

        Ritorna un elenco di odonimi presenti in ANNCSU

        :param req:
        :param codcom:
        :param denomparz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ElencoOdonimiPostRequest(
            req=req,
            codcom=codcom,
            denomparz=denomparz,
        )

        req = self._build_request_async(
            method="POST",
            path="/elencoodonimi",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ElencoOdonimiPostRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="elencoOdonimiPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.ElencoOdonimiPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostBadRequestErrorData, http_res
            )
            raise errors.ElencoOdonimiPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostNotFoundErrorData, http_res
            )
            raise errors.ElencoOdonimiPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostMethodNotAllowedErrorData, http_res
            )
            raise errors.ElencoOdonimiPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostUnprocessableEntityErrorData, http_res
            )
            raise errors.ElencoOdonimiPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoOdonimiPostInternalServerErrorData, http_res
            )
            raise errors.ElencoOdonimiPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def elenco_accessi_post(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denom: Optional[str] = None,
        accparz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ElencoAccessiPostResponse:
        r"""Ritorna un elenco di accessi presenti in ANNCSU

        Ritorna un elenco di accessi presenti in ANNCSU

        :param req:
        :param codcom:
        :param denom:
        :param accparz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ElencoAccessiPostRequest(
            req=req,
            codcom=codcom,
            denom=denom,
            accparz=accparz,
        )

        req = self._build_request(
            method="POST",
            path="/elencoaccessi",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ElencoAccessiPostRequest
            ),
            timeout_ms=timeout_ms,
            security=self.sdk_configuration.security,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="elencoAccessiPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.ElencoAccessiPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostBadRequestErrorData, http_res
            )
            raise errors.ElencoAccessiPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostNotFoundErrorData, http_res
            )
            raise errors.ElencoAccessiPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostMethodNotAllowedErrorData, http_res
            )
            raise errors.ElencoAccessiPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostUnprocessableEntityErrorData, http_res
            )
            raise errors.ElencoAccessiPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostInternalServerErrorData, http_res
            )
            raise errors.ElencoAccessiPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def elenco_accessi_post_async(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denom: Optional[str] = None,
        accparz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ElencoAccessiPostResponse:
        r"""Ritorna un elenco di accessi presenti in ANNCSU

        Ritorna un elenco di accessi presenti in ANNCSU

        :param req:
        :param codcom:
        :param denom:
        :param accparz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ElencoAccessiPostRequest(
            req=req,
            codcom=codcom,
            denom=denom,
            accparz=accparz,
        )

        req = self._build_request_async(
            method="POST",
            path="/elencoaccessi",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ElencoAccessiPostRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="elencoAccessiPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.ElencoAccessiPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostBadRequestErrorData, http_res
            )
            raise errors.ElencoAccessiPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostNotFoundErrorData, http_res
            )
            raise errors.ElencoAccessiPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostMethodNotAllowedErrorData, http_res
            )
            raise errors.ElencoAccessiPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostUnprocessableEntityErrorData, http_res
            )
            raise errors.ElencoAccessiPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoAccessiPostInternalServerErrorData, http_res
            )
            raise errors.ElencoAccessiPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def elencoodonimiprog_post(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denomparz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ElencoodonimiprogPostResponse:
        r"""Ritorna un elenco di odonimi presenti in ANNCSU incluso il progressivo nazionale

        Ritorna un elenco di odonimi presenti in ANNCSU incluso il progressivo nazionale

        :param req:
        :param codcom:
        :param denomparz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ElencoodonimiprogPostRequest(
            req=req,
            codcom=codcom,
            denomparz=denomparz,
        )

        req = self._build_request(
            method="POST",
            path="/elencoodonimiprog",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ElencoodonimiprogPostRequest
            ),
            timeout_ms=timeout_ms,
            security=self.sdk_configuration.security,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="elencoodonimiprogPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ElencoodonimiprogPostResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostBadRequestErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostNotFoundErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostMethodNotAllowedErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostMethodNotAllowedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostUnprocessableEntityErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostInternalServerErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def elencoodonimiprog_post_async(
        self,
        *,
        req: Optional[str] = None,
        codcom: Optional[str] = None,
        denomparz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ElencoodonimiprogPostResponse:
        r"""Ritorna un elenco di odonimi presenti in ANNCSU incluso il progressivo nazionale

        Ritorna un elenco di odonimi presenti in ANNCSU incluso il progressivo nazionale

        :param req:
        :param codcom:
        :param denomparz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ElencoodonimiprogPostRequest(
            req=req,
            codcom=codcom,
            denomparz=denomparz,
        )

        req = self._build_request_async(
            method="POST",
            path="/elencoodonimiprog",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ElencoodonimiprogPostRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="elencoodonimiprogPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ElencoodonimiprogPostResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostBadRequestErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostNotFoundErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostMethodNotAllowedErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostMethodNotAllowedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostUnprocessableEntityErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoodonimiprogPostInternalServerErrorData, http_res
            )
            raise errors.ElencoodonimiprogPostInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def elencoaccessiprog_post(
        self,
        *,
        req: Optional[str] = None,
        prognaz: Optional[str] = None,
        accparz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ElencoaccessiprogPostResponse:
        r"""Ritorna un elenco di accessi presenti in ANNCSU incluso il progressivo nazionale

        Ritorna un elenco di accessi presenti in ANNCSU incluso il progressivo nazionale

        :param req:
        :param prognaz:
        :param accparz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ElencoaccessiprogPostRequest(
            req=req,
            prognaz=prognaz,
            accparz=accparz,
        )

        req = self._build_request(
            method="POST",
            path="/elencoaccessiprog",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ElencoaccessiprogPostRequest
            ),
            timeout_ms=timeout_ms,
            security=self.sdk_configuration.security,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="elencoaccessiprogPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ElencoaccessiprogPostResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostBadRequestErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostNotFoundErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostMethodNotAllowedErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostMethodNotAllowedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostUnprocessableEntityErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostInternalServerErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def elencoaccessiprog_post_async(
        self,
        *,
        req: Optional[str] = None,
        prognaz: Optional[str] = None,
        accparz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.ElencoaccessiprogPostResponse:
        r"""Ritorna un elenco di accessi presenti in ANNCSU incluso il progressivo nazionale

        Ritorna un elenco di accessi presenti in ANNCSU incluso il progressivo nazionale

        :param req:
        :param prognaz:
        :param accparz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.ElencoaccessiprogPostRequest(
            req=req,
            prognaz=prognaz,
            accparz=accparz,
        )

        req = self._build_request_async(
            method="POST",
            path="/elencoaccessiprog",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.ElencoaccessiprogPostRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="elencoaccessiprogPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.ElencoaccessiprogPostResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostBadRequestErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostNotFoundErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostMethodNotAllowedErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostMethodNotAllowedError(
                response_data, http_res
            )
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostUnprocessableEntityErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.ElencoaccessiprogPostInternalServerErrorData, http_res
            )
            raise errors.ElencoaccessiprogPostInternalServerError(
                response_data, http_res
            )
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def prognazarea_post(
        self,
        *,
        req: Optional[str] = None,
        prognaz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PrognazareaPostResponse:
        r"""Cerca in ANNCSU un odonimo per progressivo nazionale e ne ritorna i dati

        Cerca in ANNCSU un odonimo per progressivo nazionale e ne ritorna i dati

        :param req:
        :param prognaz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PrognazareaPostRequest(
            req=req,
            prognaz=prognaz,
        )

        req = self._build_request(
            method="POST",
            path="/prognazarea",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.PrognazareaPostRequest
            ),
            timeout_ms=timeout_ms,
            security=self.sdk_configuration.security,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="prognazareaPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PrognazareaPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostBadRequestErrorData, http_res
            )
            raise errors.PrognazareaPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostNotFoundErrorData, http_res
            )
            raise errors.PrognazareaPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostMethodNotAllowedErrorData, http_res
            )
            raise errors.PrognazareaPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostUnprocessableEntityErrorData, http_res
            )
            raise errors.PrognazareaPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostInternalServerErrorData, http_res
            )
            raise errors.PrognazareaPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def prognazarea_post_async(
        self,
        *,
        req: Optional[str] = None,
        prognaz: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PrognazareaPostResponse:
        r"""Cerca in ANNCSU un odonimo per progressivo nazionale e ne ritorna i dati

        Cerca in ANNCSU un odonimo per progressivo nazionale e ne ritorna i dati

        :param req:
        :param prognaz:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PrognazareaPostRequest(
            req=req,
            prognaz=prognaz,
        )

        req = self._build_request_async(
            method="POST",
            path="/prognazarea",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.PrognazareaPostRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="prognazareaPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PrognazareaPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostBadRequestErrorData, http_res
            )
            raise errors.PrognazareaPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostNotFoundErrorData, http_res
            )
            raise errors.PrognazareaPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostMethodNotAllowedErrorData, http_res
            )
            raise errors.PrognazareaPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostUnprocessableEntityErrorData, http_res
            )
            raise errors.PrognazareaPostUnprocessableEntityError(
                response_data, http_res
            )
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazareaPostInternalServerErrorData, http_res
            )
            raise errors.PrognazareaPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def prognazacc_post(
        self,
        *,
        req: Optional[str] = None,
        prognazacc: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PrognazaccPostResponse:
        r"""Cerca in ANNCSU un accesso per progressivo nazionale accesso e ne ritorna i dati comprensivi dell'odonimo

        Cerca in ANNCSU un accesso per progressivo nazionale accesso e ne ritorna i dati comprensivi dell'odonimo

        :param req:
        :param prognazacc:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PrognazaccPostRequest(
            req=req,
            prognazacc=prognazacc,
        )

        req = self._build_request(
            method="POST",
            path="/prognazacc",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.PrognazaccPostRequest
            ),
            timeout_ms=timeout_ms,
            security=self.sdk_configuration.security,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="prognazaccPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PrognazaccPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostBadRequestErrorData, http_res
            )
            raise errors.PrognazaccPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostNotFoundErrorData, http_res
            )
            raise errors.PrognazaccPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostMethodNotAllowedErrorData, http_res
            )
            raise errors.PrognazaccPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostUnprocessableEntityErrorData, http_res
            )
            raise errors.PrognazaccPostUnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostInternalServerErrorData, http_res
            )
            raise errors.PrognazaccPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def prognazacc_post_async(
        self,
        *,
        req: Optional[str] = None,
        prognazacc: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.PrognazaccPostResponse:
        r"""Cerca in ANNCSU un accesso per progressivo nazionale accesso e ne ritorna i dati comprensivi dell'odonimo

        Cerca in ANNCSU un accesso per progressivo nazionale accesso e ne ritorna i dati comprensivi dell'odonimo

        :param req:
        :param prognazacc:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.PrognazaccPostRequest(
            req=req,
            prognazacc=prognazacc,
        )

        req = self._build_request_async(
            method="POST",
            path="/prognazacc",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=False,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.PrognazaccPostRequest
            ),
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="prognazaccPost",
                oauth2_scopes=[],
                security_source=None,
            ),
            request=req,
            error_status_codes=["400", "404", "405", "422", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(models.PrognazaccPostResponse, http_res)
        if utils.match_response(http_res, "400", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostBadRequestErrorData, http_res
            )
            raise errors.PrognazaccPostBadRequestError(response_data, http_res)
        if utils.match_response(http_res, "404", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostNotFoundErrorData, http_res
            )
            raise errors.PrognazaccPostNotFoundError(response_data, http_res)
        if utils.match_response(http_res, "405", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostMethodNotAllowedErrorData, http_res
            )
            raise errors.PrognazaccPostMethodNotAllowedError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostUnprocessableEntityErrorData, http_res
            )
            raise errors.PrognazaccPostUnprocessableEntityError(response_data, http_res)
        if utils.match_response(http_res, "500", "application/problem+json"):
            response_data = unmarshal_json_response(
                errors.PrognazaccPostInternalServerErrorData, http_res
            )
            raise errors.PrognazaccPostInternalServerError(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)



"""Response validation against OpenAPI specifications."""

from dataclasses import dataclass
from pathlib import Path
from typing import Any, Optional

import httpx


@dataclass
class ValidationConfig:
    """Configuration for response validation."""

    enabled: bool = False
    """Whether response validation is enabled"""

    openapi_spec_path: Optional[Path] = None
    """Path to the OpenAPI specification file"""

    strict: bool = True
    """Whether to raise exceptions on validation errors or just log warnings"""


class ResponseValidator:
    """
    Validates HTTP responses against OpenAPI specifications.

    This validator uses openapi-pydantic to parse OpenAPI specs and validate
    that API responses match the expected schema.

    Note: This validator requires openapi-pydantic and pyyaml to be installed.
    These are included in the dev dependencies but not in the main SDK.
    """

    def __init__(self, spec_path: Path):
        """
        Initialize the response validator.

        Args:
            spec_path: Path to the OpenAPI specification YAML file

        Raises:
            ImportError: If openapi-pydantic or pyyaml are not installed
            FileNotFoundError: If the spec file doesn't exist
        """
        try:
            import yaml  # noqa: F401
            from openapi_pydantic import OpenAPI  # noqa: F401
        except ImportError as e:
            raise ImportError(
                "Response validation requires openapi-pydantic and pyyaml. "
                "These are included in dev dependencies. "
                "Install with: uv sync --dev"
            ) from e

        if not spec_path.exists():
            raise FileNotFoundError(f"OpenAPI spec not found: {spec_path}")

        self.spec_path = spec_path
        self._load_spec()

    def _load_spec(self) -> None:
        """Load and parse the OpenAPI specification."""
        import yaml

        with open(self.spec_path) as f:
            spec_dict = yaml.safe_load(f)

        # Detect OpenAPI version and use appropriate parser
        openapi_version = spec_dict.get("openapi", "")

        try:
            if openapi_version.startswith("3.0"):
                from openapi_pydantic.v3.v3_0 import OpenAPI

                self.spec = OpenAPI.model_validate(spec_dict)
            elif openapi_version.startswith("3.1"):
                from openapi_pydantic.v3.v3_1 import OpenAPI

                self.spec = OpenAPI.model_validate(spec_dict)
            else:
                raise ValueError(
                    f"Unsupported OpenAPI version: {openapi_version}. "
                    f"Supported versions: 3.0.x, 3.1.x"
                )
        except Exception as e:
            raise ValueError(f"Invalid OpenAPI specification: {e}") from e

    def validate_response(
        self,
        response: httpx.Response,
        operation_id: str,
    ) -> tuple[bool, list[str]]:
        """
        Validate an HTTP response against the OpenAPI spec.

        Args:
            response: The HTTP response to validate
            operation_id: The OpenAPI operation ID (e.g., "esisteOdonimoGetQueryParam")

        Returns:
            Tuple of (is_valid, errors) where errors is a list of validation error messages
        """
        errors = []

        # Find the operation in the spec
        operation = self._find_operation(operation_id)
        if not operation:
            errors.append(f"Operation '{operation_id}' not found in OpenAPI spec")
            return False, errors

        # Get expected response schema for this status code
        status_code = str(response.status_code)
        if not operation.responses:
            errors.append(f"No responses defined for operation '{operation_id}'")
            return False, errors

        response_spec = operation.responses.get(status_code)
        if not response_spec:
            # Try default response
            response_spec = operation.responses.get("default")
            if not response_spec:
                errors.append(
                    f"No response schema defined for status code {status_code} "
                    f"in operation '{operation_id}'"
                )
                return False, errors

        # Validate response content type
        content_type = response.headers.get("content-type", "").split(";")[0].strip()

        if not response_spec.content:
            # Response should have no content
            if response.content:
                errors.append(
                    f"Response should have no content but got: {len(response.content)} bytes"
                )
                return False, errors
            return True, []

        # Check if content type is expected
        if content_type not in response_spec.content:
            expected_types = list(response_spec.content.keys())
            errors.append(
                f"Unexpected content type '{content_type}'. "
                f"Expected one of: {expected_types}"
            )
            return False, errors

        # Validate response body against schema
        try:
            response_data = response.json()
        except Exception as e:
            errors.append(f"Failed to parse response JSON: {e}")
            return False, errors

        # Get the schema for this content type
        media_type = response_spec.content[content_type]
        if not media_type.media_type_schema:
            # No schema defined, consider valid
            return True, []

        # Validate against schema
        # Note: openapi-pydantic parses the schema but doesn't validate data against it
        # For full validation, we'd need jsonschema or similar
        # For now, we do basic structure validation
        validation_errors = self._validate_against_schema(
            response_data, media_type.media_type_schema
        )

        if validation_errors:
            errors.extend(validation_errors)
            return False, errors

        return True, []

    def _find_operation(self, operation_id: str):
        """Find an operation in the spec by operation ID."""
        if not self.spec.paths:
            return None

        for path_item in self.spec.paths.values():
            for operation in [
                path_item.get,
                path_item.post,
                path_item.put,
                path_item.delete,
                path_item.patch,
            ]:
                if operation and operation.operationId == operation_id:
                    return operation

        return None

    def _validate_against_schema(self, data: Any, schema: Any) -> list[str]:
        """
        Basic validation of data against OpenAPI schema.

        This is a simplified validation. For production use, consider
        integrating jsonschema for complete validation.
        """
        errors = []

        # This is a placeholder for more comprehensive validation
        # In a full implementation, you'd use jsonschema here
        # For now, we just check basic type matching

        if not isinstance(data, dict):
            if hasattr(schema, "type") and schema.type != type(data).__name__:
                errors.append(
                    f"Type mismatch: expected {schema.type}, got {type(data).__name__}"
                )

        return errors
